@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2011,2013-2016                      Université de Bordeaux
- * Copyright (C) 2012,2013                                Inria
- * Copyright (C) 2010-2013,2015-2017                      CNRS
+ * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -123,7 +121,8 @@ int main(int argc, char **argv)
 	end = starpu_timing_now();
 
 #ifdef STARPU_USE_OPENCL
-	starpu_opencl_unload_opencl(&opencl_program);
+	ret = starpu_opencl_unload_opencl(&opencl_program);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_opencl_unload_opencl");
 #endif
 
 	FPRINTF(stderr, "array -> %f, %f, %f, %f\n", float_array[0],
