@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2012-2013                                Inria
- * Copyright (C) 2012-2015                                CNRS
- * Copyright (C) 2013-2015, 2018                                Université de Bordeaux
+ * Copyright (C) 2012-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +20,7 @@
 
 static int complex_pointer_is_inside(void *data_interface, unsigned node, void *ptr)
 {
+	(void)node;
 	struct starpu_complex_interface *complex_interface = data_interface;
 
 	return ((char*) ptr >= (char*) &complex_interface->real &&
@@ -139,7 +138,7 @@ static int complex_pack_data(starpu_data_handle_t handle, unsigned node, void **
 	if (ptr != NULL)
 	{
 		char *data;
-		starpu_malloc_flags((void**) &data, *count, 0);
+		data = (void*) starpu_malloc_on_node_flags(node, *count, 0);
 		*ptr = data;
 		memcpy(data, complex_interface->real, complex_interface->nx*sizeof(double));
 		memcpy(data+complex_interface->nx*sizeof(double), complex_interface->imaginary, complex_interface->nx*sizeof(double));
@@ -160,6 +159,8 @@ static int complex_unpack_data(starpu_data_handle_t handle, unsigned node, void
 	memcpy(complex_interface->real, data, complex_interface->nx*sizeof(double));
 	memcpy(complex_interface->imaginary, data+complex_interface->nx*sizeof(double), complex_interface->nx*sizeof(double));
 
+	starpu_free_on_node_flags(node, (uintptr_t) ptr, count, 0);
+
 	return 0;
 }
 
@@ -169,6 +170,14 @@ static starpu_ssize_t complex_describe(void *data_interface, char *buf, size_t s
 	return snprintf(buf, size, "Complex%d", complex_interface->nx);
 }
 
+static int complex_compare(void *data_interface_a, void *data_interface_b)
+{
+	struct starpu_complex_interface *complex_a = (struct starpu_complex_interface *) data_interface_a;
+	struct starpu_complex_interface *complex_b = (struct starpu_complex_interface *) data_interface_b;
+
+	return (complex_a->nx == complex_b->nx);
+}
+
 static int copy_any_to_any(void *src_interface, unsigned src_node,
 			   void *dst_interface, unsigned dst_node,
 			   void *async_data)
@@ -205,11 +214,12 @@ static struct starpu_data_interface_ops interface_complex_ops =
 	.footprint = complex_footprint,
 	.interfaceid = STARPU_UNKNOWN_INTERFACE_ID,
 	.interface_size = sizeof(struct starpu_complex_interface),
-	.handle_to_pointer = NULL,
+	.to_pointer = NULL,
 	.pointer_is_inside = complex_pointer_is_inside,
 	.pack_data = complex_pack_data,
 	.unpack_data = complex_unpack_data,
-	.describe = complex_describe
+	.describe = complex_describe,
+	.compare = complex_compare
 };
 
 void starpu_complex_data_register(starpu_data_handle_t *handleptr, unsigned home_node, double *real, double *imaginary, int nx)
