@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,7 @@ void cpu_codelet_A(void *descr[], void *_args)
 {
 	(void)descr;
 	int *arg = _args;
-	*arg = 1;
+	STARPU_ATOMIC_OR(arg, 1);
 	fprintf(stderr,"A");
 }
 
