@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2013       Joris Pablo
  * Copyright (C) 2013       Thibaut Lambert
  * Copyright (C) 2020       Federal University of Rio Grande do Sul (UFRGS)
@@ -66,6 +66,7 @@ struct starpu_fxt_options
 	char *data_path;
 	char *anim_path;
 	char *states_path;
+	char *dir;
 
 	/**
 	   In case we are going to gather multiple traces (e.g in the case of
@@ -107,6 +108,8 @@ struct starpu_fxt_options
 };
 
 void starpu_fxt_options_init(struct starpu_fxt_options *options);
+void starpu_fxt_options_shutdown(struct starpu_fxt_options *options);
+void starpu_fxt_options_set_dir(struct starpu_fxt_options *options);
 void starpu_fxt_generate_trace(struct starpu_fxt_options *options);
 
 /**
@@ -134,6 +137,11 @@ void starpu_fxt_start_profiling(void);
 void starpu_fxt_stop_profiling(void);
 void starpu_fxt_write_data_trace(char *filename_in);
 
+/**
+    Wrapper to get value of env variable STARPU_FXT_TRACE
+*/
+int starpu_fxt_is_enabled();
+
 /**
    Add an event in the execution trace if FxT is enabled.
 */
