@@ -1,10 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013-2017                                Inria
- * Copyright (C) 2010-2015,2017,2019                      CNRS
- * Copyright (C) 2009-2014,2016,2017,2019                 Université de Bordeaux
- * Copyright (C) 2013                                     Thibaut Lambert
- * Copyright (C) 2016                                     Uppsala University
+ * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013       Thibaut Lambert
+ * Copyright (C) 2016       Uppsala University
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -40,6 +38,9 @@ extern "C"
    @{
 */
 
+/**
+  Memory node Type
+*/
 enum starpu_node_kind
 {
 	STARPU_UNUSED=0,
@@ -153,8 +154,8 @@ struct starpu_worker_collection
 	void (*init_iterator_for_parallel_tasks)(struct starpu_worker_collection *workers, struct starpu_sched_ctx_iterator *it, struct starpu_task *task);
 };
 
-extern struct starpu_worker_collection worker_list;
-extern struct starpu_worker_collection worker_tree;
+extern struct starpu_worker_collection starpu_worker_list;
+extern struct starpu_worker_collection starpu_worker_tree;
 
 /**
    Return the number of workers (i.e. processing units executing
@@ -346,8 +347,20 @@ unsigned starpu_worker_get_local_memory_node(void);
 */
 unsigned starpu_worker_get_memory_node(unsigned workerid);
 
+/**
+   Return the number of memory nodes
+*/
 unsigned starpu_memory_nodes_get_count(void);
+
+/**
+   Return in \p name the name of a memory node (NUMA 0, CUDA 0, etc.)
+   \p size is the size of the \p name array.
+*/
 int starpu_memory_node_get_name(unsigned node, char *name, size_t size);
+
+/**
+   Return the number of NUMA nodes used by StarPU
+*/
 int starpu_memory_nodes_get_numa_count(void);
 
 /**
@@ -488,7 +501,7 @@ int starpu_combined_worker_get_size(void);
 
 /**
    Return the rank of the current thread within the combined worker.
-   Can only be used in ::STARPU_FORKJOIN parallel tasks, to know which
+   Can only be used in ::STARPU_SPMD parallel tasks, to know which
    part of the task to work on.
 */
 int starpu_combined_worker_get_rank(void);
