@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013,2016                                Inria
- * Copyright (C) 2010-2019                                CNRS
- * Copyright (C) 2009-2012,2014-2018                      Université de Bordeaux
+ * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -52,9 +50,9 @@ extern "C"
 int starpu_mpi_init_conf(int *argc, char ***argv, int initialize_mpi, MPI_Comm comm, struct starpu_conf *conf);
 
 /**
-   Same as starpu_mpi_init_conf(), except that this does not
-   initialize the StarPU library. The caller thus has to call
-   starpu_init() before this.
+   Same as starpu_mpi_init_conf(), except that this does not initialize the
+   StarPU library. The caller thus has to call starpu_init() before this, and it
+   can not reserve a core for the MPI communications.
 */
 int starpu_mpi_init_comm(int *argc, char ***argv, int initialize_mpi, MPI_Comm comm);
 
@@ -151,7 +149,7 @@ void starpu_mpi_set_communication_tag(int tag);
 typedef void *starpu_mpi_req;
 
 /**
-   Define the type which can be used to set communication tag when exchanging data.
+   Type of the message tag.
 */
 typedef int64_t starpu_mpi_tag_t;
 
@@ -193,6 +191,8 @@ int starpu_mpi_send_prio(starpu_data_handle_t data_handle, int dest, starpu_mpi_
    Perform a standard-mode, blocking receive in \p data_handle from
    the node \p source using the message tag \p data_tag within the
    communicator \p comm.
+   The value of \p status cannot be NULL, use the predefined value
+   MPI_STATUS_IGNORE to ignore the status.
 */
 int starpu_mpi_recv(starpu_data_handle_t data_handle, int source, starpu_mpi_tag_t data_tag, MPI_Comm comm, MPI_Status *status);
 
@@ -273,6 +273,8 @@ int starpu_mpi_issend_detached_prio(starpu_data_handle_t data_handle, int dest,
 
 /**
    Return when the operation identified by request \p req is complete.
+   The value of \p status cannot be NULL, use the predefined value
+   MPI_STATUS_IGNORE to ignore the status.
 */
 int starpu_mpi_wait(starpu_mpi_req *req, MPI_Status *status);
 
@@ -339,24 +341,41 @@ int starpu_mpi_isend_array_detached_unlock_tag_prio(unsigned array_size, starpu_
 */
 int starpu_mpi_irecv_array_detached_unlock_tag(unsigned array_size, starpu_data_handle_t *data_handle, int *source, starpu_mpi_tag_t *data_tag, MPI_Comm *comm, starpu_tag_t tag);
 
-typedef void (*starpu_mpi_datatype_allocate_func_t)(starpu_data_handle_t, MPI_Datatype *);
+typedef int (*starpu_mpi_datatype_allocate_func_t)(starpu_data_handle_t, MPI_Datatype *);
 typedef void (*starpu_mpi_datatype_free_func_t)(MPI_Datatype *);
 
 /**
    Register functions to create and free a MPI datatype for the given
    handle.
+   Similar to starpu_mpi_interface_datatype_register().
    It is important that the function is called before any
    communication can take place for a data with the given handle. See
    \ref ExchangingUserDefinedDataInterface for an example.
 */
 int starpu_mpi_datatype_register(starpu_data_handle_t handle, starpu_mpi_datatype_allocate_func_t allocate_datatype_func, starpu_mpi_datatype_free_func_t free_datatype_func);
 
+/**
+   Register functions to create and free a MPI datatype for the given
+   interface id.
+   Similar to starpu_mpi_datatype_register().
+   It is important that the function is called before any
+   communication can take place for a data with the given handle. See
+   \ref ExchangingUserDefinedDataInterface for an example.
+*/
+int starpu_mpi_interface_datatype_register(enum starpu_data_interface_id id, starpu_mpi_datatype_allocate_func_t allocate_datatype_func, starpu_mpi_datatype_free_func_t free_datatype_func);
+
 /**
    Unregister the MPI datatype functions stored for the interface of
    the given handle.
 */
 int starpu_mpi_datatype_unregister(starpu_data_handle_t handle);
 
+/**
+   Unregister the MPI datatype functions stored for the interface of
+   the given interface id. Similar to starpu_mpi_datatype_unregister().
+*/
+int starpu_mpi_interface_datatype_unregister(enum starpu_data_interface_id id);
+
 /** @} */
 
 /**
@@ -400,6 +419,19 @@ void starpu_mpi_cache_flush_all_data(MPI_Comm comm);
 */
 int starpu_mpi_cached_receive(starpu_data_handle_t data_handle);
 
+/**
+ * If \p data is already available in the reception cache, return 1
+ * If \p data is NOT available in the reception cache, add it to the
+ * cache and return 0
+ * Return 0 if the communication cache is not enabled
+ */
+int starpu_mpi_cached_receive_set(starpu_data_handle_t data);
+
+/**
+ * Remove \p data from the reception cache
+ */
+void starpu_mpi_cached_receive_clear(starpu_data_handle_t data);
+
 /**
    Test whether \p data_handle is cached for emission to node \p dest,
    i.e. the value was previously sent to \p dest, and not flushed
@@ -407,10 +439,25 @@ int starpu_mpi_cached_receive(starpu_data_handle_t data_handle);
 */
 int starpu_mpi_cached_send(starpu_data_handle_t data_handle, int dest);
 
+/**
+ * If \p data is already available in the emission cache for node
+ * \p dest, return 1
+ * If \p data is NOT available in the emission cache for node \p dest,
+ * add it to the cache and return 0
+ * Return 0 if the communication cache is not enabled
+ */
+int starpu_mpi_cached_send_set(starpu_data_handle_t data, int dest);
+
+/**
+ * Remove \p data from the emission cache
+ */
+void starpu_mpi_cached_send_clear(starpu_data_handle_t data);
+
 /** @} */
 
 /**
    @name MPI Insert Task
+   \anchor MPIInsertTask
    @{
 */
 
@@ -519,7 +566,7 @@ starpu_mpi_tag_t starpu_mpi_data_get_tag(starpu_data_handle_t handle);
 	If there is several nodes owning data in ::STARPU_W mode, a
 	node will be selected according to a given node selection
 	policy (see ::STARPU_NODE_SELECTION_POLICY or
-	starpu_mpi_node_selection_set_current_policy()) 
+	starpu_mpi_node_selection_set_current_policy())
 	<li>
 	The argument ::STARPU_EXECUTE_ON_NODE followed by an integer
 	can be used to specify the node;
@@ -617,7 +664,15 @@ void starpu_mpi_data_migrate(MPI_Comm comm, starpu_data_handle_t handle, int new
    @{
 */
 
+
+/**
+   Define the current policy
+ */
 #define STARPU_MPI_NODE_SELECTION_CURRENT_POLICY -1
+/**
+   Define the policy in which the selected node is the one having the
+   most data in ::STARPU_R mode
+*/
 #define STARPU_MPI_NODE_SELECTION_MOST_R_DATA    0
 
 typedef int (*starpu_mpi_select_node_policy_func_t)(int me, int nb_nodes, struct starpu_data_descr *descr, int nb_data);
