@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -85,6 +85,7 @@ void check_variable(starpu_data_handle_t handle, int i, int rank, int *error)
 {
 	int other_rank = rank%2 == 0 ? rank+1 : rank-1;
 
+	starpu_data_acquire_on_node(handle, starpu_worker_get_local_memory_node(), STARPU_R);
 	int *rvalue = (int *)starpu_data_get_local_ptr(handle);
 	if (*rvalue != i*other_rank)
 	{
@@ -95,6 +96,7 @@ void check_variable(starpu_data_handle_t handle, int i, int rank, int *error)
 	{
 		FPRINTF_MPI(stderr, "Correct received value: %d == %d\n", *rvalue, i*other_rank);
 	}
+	starpu_data_release(handle);
 }
 
 int exchange_variable(int rank)
