@@ -1,10 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2018                                Inria
- * Copyright (C) 2017                                     Arthur Chevalier
- * Copyright (C) 2012-2019                                CNRS
- * Copyright (C) 2012-2019                                Université de Bordeaux
- * Copyright (C) 2016                                     Uppsala University
+ * Copyright (C) 2011-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016       Uppsala University
+ * Copyright (C) 2017       Arthur Chevalier
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -33,7 +31,7 @@ enum _starpu_ctx_change_op
 static starpu_pthread_mutex_t sched_ctx_manag = STARPU_PTHREAD_MUTEX_INITIALIZER;
 static starpu_pthread_mutex_t finished_submit_mutex = STARPU_PTHREAD_MUTEX_INITIALIZER;
 static struct starpu_task stop_submission_task = STARPU_TASK_INITIALIZER;
-starpu_pthread_key_t sched_ctx_key;
+static starpu_pthread_key_t sched_ctx_key;
 static unsigned with_hypervisor = 0;
 static double hyp_start_sample[STARPU_NMAX_SCHED_CTXS];
 static double hyp_start_allow_sample[STARPU_NMAX_SCHED_CTXS];
@@ -1137,8 +1135,8 @@ static void fetch_tasks_from_empty_ctx_list(struct _starpu_sched_ctx *sched_ctx)
 
 		/* if no workers are able to execute the task, it will be put
 		 * in the empty_ctx_tasks list forever again */
-		unsigned nworkers = _starpu_nworkers_able_to_execute_task(old_task, sched_ctx);
-		STARPU_ASSERT(nworkers > 0);
+		unsigned able = _starpu_workers_able_to_execute_task(old_task, sched_ctx);
+		STARPU_ASSERT(able);
 
 		int ret =  _starpu_push_task_to_workers(old_task);
 		/* if we should stop poping from empty ctx tasks */
@@ -1421,9 +1419,9 @@ void starpu_sched_ctx_remove_workers(int *workers_to_remove, unsigned nworkers_t
 	}
 }
 
-int _starpu_nworkers_able_to_execute_task(struct starpu_task *task, struct _starpu_sched_ctx *sched_ctx)
+int _starpu_workers_able_to_execute_task(struct starpu_task *task, struct _starpu_sched_ctx *sched_ctx)
 {
-	unsigned nworkers = 0;
+	unsigned able = 0;
 
 	_starpu_sched_ctx_lock_read(sched_ctx->id);
 	struct starpu_worker_collection *workers = sched_ctx->workers;
@@ -1436,11 +1434,14 @@ int _starpu_nworkers_able_to_execute_task(struct starpu_task *task, struct _star
 		unsigned worker = workers->get_next(workers, &it);
 		STARPU_ASSERT_MSG(worker < STARPU_NMAXWORKERS, "worker id %u", worker);
 		if (starpu_worker_can_execute_task_first_impl(worker, task, NULL))
-			nworkers++;
+		{
+			able++;
+			break;
+		}
 	}
 	_starpu_sched_ctx_unlock_read(sched_ctx->id);
 
-	return nworkers;
+	return able;
 }
 
 /* unused sched_ctx have the id STARPU_NMAX_SCHED_CTXS */
@@ -1771,27 +1772,27 @@ struct starpu_worker_collection* starpu_sched_ctx_create_worker_collection(unsig
 	{
 #ifdef STARPU_HAVE_HWLOC
 	case STARPU_WORKER_TREE:
-		sched_ctx->workers->has_next = worker_tree.has_next;
-		sched_ctx->workers->get_next = worker_tree.get_next;
-		sched_ctx->workers->add = worker_tree.add;
-		sched_ctx->workers->remove = worker_tree.remove;
-		sched_ctx->workers->init = worker_tree.init;
-		sched_ctx->workers->deinit = worker_tree.deinit;
-		sched_ctx->workers->init_iterator = worker_tree.init_iterator;
-		sched_ctx->workers->init_iterator_for_parallel_tasks = worker_tree.init_iterator_for_parallel_tasks;
+		sched_ctx->workers->has_next = starpu_worker_tree.has_next;
+		sched_ctx->workers->get_next = starpu_worker_tree.get_next;
+		sched_ctx->workers->add = starpu_worker_tree.add;
+		sched_ctx->workers->remove = starpu_worker_tree.remove;
+		sched_ctx->workers->init = starpu_worker_tree.init;
+		sched_ctx->workers->deinit = starpu_worker_tree.deinit;
+		sched_ctx->workers->init_iterator = starpu_worker_tree.init_iterator;
+		sched_ctx->workers->init_iterator_for_parallel_tasks = starpu_worker_tree.init_iterator_for_parallel_tasks;
 		sched_ctx->workers->type = STARPU_WORKER_TREE;
 		break;
 #endif
 //	case STARPU_WORKER_LIST:
 	default:
-		sched_ctx->workers->has_next = worker_list.has_next;
-		sched_ctx->workers->get_next = worker_list.get_next;
-		sched_ctx->workers->add = worker_list.add;
-		sched_ctx->workers->remove = worker_list.remove;
-		sched_ctx->workers->init = worker_list.init;
-		sched_ctx->workers->deinit = worker_list.deinit;
-		sched_ctx->workers->init_iterator = worker_list.init_iterator;
-		sched_ctx->workers->init_iterator_for_parallel_tasks = worker_list.init_iterator_for_parallel_tasks;
+		sched_ctx->workers->has_next = starpu_worker_list.has_next;
+		sched_ctx->workers->get_next = starpu_worker_list.get_next;
+		sched_ctx->workers->add = starpu_worker_list.add;
+		sched_ctx->workers->remove = starpu_worker_list.remove;
+		sched_ctx->workers->init = starpu_worker_list.init;
+		sched_ctx->workers->deinit = starpu_worker_list.deinit;
+		sched_ctx->workers->init_iterator = starpu_worker_list.init_iterator;
+		sched_ctx->workers->init_iterator_for_parallel_tasks = starpu_worker_list.init_iterator_for_parallel_tasks;
 		sched_ctx->workers->type = STARPU_WORKER_LIST;
 		break;
 
@@ -2168,7 +2169,8 @@ unsigned _starpu_sched_ctx_last_worker_awake(struct _starpu_worker *worker)
 	 * awake. In the worst case, both workers will follow this pessimistic
 	 * path and perform one more scheduling loop */
 	STARPU_HG_DISABLE_CHECKING(_starpu_config.workers[worker->workerid].status);
-	STARPU_ASSERT(_starpu_config.workers[worker->workerid].status == STATUS_SLEEPING);
+	STARPU_ASSERT(_starpu_config.workers[worker->workerid].status == STATUS_SLEEPING
+	           || _starpu_config.workers[worker->workerid].status == STATUS_SLEEPING_SCHEDULING);
 	STARPU_HG_ENABLE_CHECKING(_starpu_config.workers[worker->workerid].status);
 	struct _starpu_sched_ctx_list_iterator list_it;
 
@@ -2202,7 +2204,8 @@ unsigned _starpu_sched_ctx_last_worker_awake(struct _starpu_worker *worker)
 					 * pessimistic path and assume that they are
 					 * the last worker awake */
 					STARPU_HG_DISABLE_CHECKING(_starpu_config.workers[workerid].status);
-					const int cond = _starpu_config.workers[workerid].status != STATUS_SLEEPING;
+					const int cond = _starpu_config.workers[workerid].status != STATUS_SLEEPING
+					              && _starpu_config.workers[workerid].status != STATUS_SLEEPING_SCHEDULING;
 					STARPU_HG_ENABLE_CHECKING(_starpu_config.workers[workerid].status);
 
 					if (cond)
