@@ -480,7 +480,11 @@ void _starpu_simgrid_init_early(int *argc STARPU_ATTRIBUTE_UNUSED, char ***argv
 #endif
 		/* We didn't catch application's main. */
 		/* Start maestro as a separate thread */
+#ifdef HAVE_SIMGRID_SET_MAESTRO
+		simgrid_set_maestro(maestro, NULL);
+#else
 		SIMIX_set_maestro(maestro, NULL);
+#endif
 		/* Initialize simgrid */
 		_starpu_start_simgrid(argc, *argv);
 
@@ -488,7 +492,7 @@ void _starpu_simgrid_init_early(int *argc STARPU_ATTRIBUTE_UNUSED, char ***argv
 		void **tsd;
 		_STARPU_CALLOC(tsd, MAX_TSD+1, sizeof(void*));
 
-#if defined(HAVE_SG_ACTOR_ATTACH) && defined (HAVE_SG_ACTOR_DATA)
+#if defined(HAVE_SG_ACTOR_ATTACH) && (defined (HAVE_SG_ACTOR_DATA) || defined(HAVE_SG_ACTOR_GET_DATA))
 		sg_actor_t actor = sg_actor_attach("main", NULL, _starpu_simgrid_get_host_by_name("MAIN"), NULL);
 #ifdef HAVE_SG_ACTOR_SET_DATA
 		sg_actor_set_data(actor, tsd);
@@ -515,7 +519,7 @@ void _starpu_simgrid_init_early(int *argc STARPU_ATTRIBUTE_UNUSED, char ***argv
 #ifndef STARPU_STATIC_ONLY
 		_STARPU_ERROR("Simgrid currently does not support privatization for dynamically-linked libraries in SMPI. Please reconfigure and build StarPU with --disable-shared");
 #endif
-#if defined(HAVE_MSG_PROCESS_USERDATA_INIT) && !defined(HAVE_SG_ACTOR_DATA)
+#if defined(HAVE_MSG_PROCESS_USERDATA_INIT) && !(defined(HAVE_SG_ACTOR_DATA) || defined(HAVE_SG_ACTOR_GET_DATA))
 		MSG_process_userdata_init();
 #endif
 		void **tsd;
@@ -632,7 +636,7 @@ void _starpu_simgrid_deinit(void)
 
 struct task
 {
-#ifdef HAVE_SG_ACTOR_SELF_EXECUTE
+#if defined(HAVE_SG_ACTOR_SELF_EXECUTE) || defined(HAVE_SG_ACTOR_EXECUTE)
 	double flops;
 #else
 	msg_task_t task;
@@ -714,7 +718,7 @@ void _starpu_simgrid_submit_job(int workerid, struct _starpu_job *j, struct star
 {
 	struct starpu_task *starpu_task = j->task;
 	double flops;
-#ifndef HAVE_SG_ACTOR_SELF_EXECUTE
+#if !(defined(HAVE_SG_ACTOR_SELF_EXECUTE) || defined(HAVE_SG_ACTOR_EXECUTE))
 	msg_task_t simgrid_task;
 #endif
 
@@ -749,7 +753,7 @@ void _starpu_simgrid_submit_job(int workerid, struct _starpu_job *j, struct star
 #endif
 #endif
 
-#ifndef HAVE_SG_ACTOR_SELF_EXECUTE
+#if !(defined(HAVE_SG_ACTOR_SELF_EXECUTE) || defined(HAVE_SG_ACTOR_EXECUTE))
 	simgrid_task = MSG_task_create(_starpu_job_get_task_name(j), flops, 0, NULL);
 #endif
 
@@ -773,7 +777,7 @@ void _starpu_simgrid_submit_job(int workerid, struct _starpu_job *j, struct star
 		struct task *task;
 		struct worker_runner *w = &worker_runner[workerid];
 		_STARPU_MALLOC(task, sizeof(*task));
-#ifdef HAVE_SG_ACTOR_SELF_EXECUTE
+#if defined(HAVE_SG_ACTOR_SELF_EXECUTE) || defined(HAVE_SG_ACTOR_EXECUTE)
 		task->flops = flops;
 #else
 		task->task = simgrid_task;
