@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2008-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2010       Mehdi Juhoor
  * Copyright (C) 2011       Télécom-SudParis
  * Copyright (C) 2013       Thibaut Lambert
@@ -31,7 +31,7 @@
 #ifdef HAVE_CUDA_GL_INTEROP_H
 #include <cuda_gl_interop.h>
 #endif
-#ifdef HAVE_LIBNVIDIA_ML
+#ifdef STARPU_HAVE_LIBNVIDIA_ML
 #include <nvml.h>
 #endif
 #include <datawizard/memory_manager.h>
@@ -57,11 +57,14 @@
 #endif
 #endif
 
+/* Consider a rough 10% overhead cost */
+#define FREE_MARGIN 0.9
+
 /* the number of CUDA devices */
 static int ncudagpus = -1;
 
 static size_t global_mem[STARPU_MAXCUDADEVS];
-#ifdef HAVE_LIBNVIDIA_ML
+#ifdef STARPU_HAVE_LIBNVIDIA_ML
 static nvmlDevice_t nvmlDev[STARPU_MAXCUDADEVS];
 #endif
 int _starpu_cuda_bus_ids[STARPU_MAXCUDADEVS+STARPU_MAXNUMANODES][STARPU_MAXCUDADEVS+STARPU_MAXNUMANODES];
@@ -103,6 +106,25 @@ static size_t _starpu_cuda_get_global_mem_size(unsigned devid)
 	return global_mem[devid];
 }
 
+#ifdef STARPU_HAVE_LIBNVIDIA_ML
+nvmlDevice_t _starpu_cuda_get_nvmldev(struct cudaDeviceProp *props)
+{
+	char busid[13];
+	nvmlDevice_t ret;
+
+	snprintf(busid, sizeof(busid), "%04x:%02x:%02x.0", props->pciDomainID, props->pciBusID, props->pciDeviceID);
+	if (nvmlDeviceGetHandleByPciBusId(busid, &ret) != NVML_SUCCESS)
+		ret = NULL;
+
+	return ret;
+}
+
+nvmlDevice_t starpu_cuda_get_nvmldev(unsigned devid)
+{
+	return nvmlDev[devid];
+}
+#endif
+
 void
 _starpu_cuda_discover_devices (struct _starpu_machine_config *config)
 {
@@ -118,7 +140,7 @@ _starpu_cuda_discover_devices (struct _starpu_machine_config *config)
 	if (STARPU_UNLIKELY(cures != cudaSuccess))
 		cnt = 0;
 	config->topology.nhwcudagpus = cnt;
-#ifdef HAVE_LIBNVIDIA_ML
+#ifdef STARPU_HAVE_LIBNVIDIA_ML
 	nvmlInit();
 #endif
 #endif
@@ -153,8 +175,7 @@ static void _starpu_cuda_limit_gpu_mem_if_needed(unsigned devid)
 #if defined(STARPU_USE_CUDA) || defined(STARPU_SIMGRID)
 	if (limit == -1)
 	{
-		/* Use 90% of the available memory by default.  */
-		limit = totalGlobalMem / (1024*1024) * 0.9;
+		limit = totalGlobalMem / (1024*1024) * FREE_MARGIN;
 	}
 #endif
 
@@ -733,10 +754,8 @@ int _starpu_cuda_driver_init(struct _starpu_worker_set *worker_set)
 
 #if defined(STARPU_HAVE_BUSID) && !defined(STARPU_SIMGRID)
 #if defined(STARPU_HAVE_DOMAINID) && !defined(STARPU_SIMGRID)
-#ifdef HAVE_LIBNVIDIA_ML
-		char busid[13];
-		snprintf(busid, sizeof(busid), "%04x:%02x:%02x.0", props[devid].pciDomainID, props[devid].pciBusID, props[devid].pciDeviceID);
-		nvmlDeviceGetHandleByPciBusId(busid, &nvmlDev[devid]);
+#ifdef STARPU_HAVE_LIBNVIDIA_ML
+		nvmlDev[devid] = _starpu_cuda_get_nvmldev(&props[devid]);
 #endif
 		if (props[devid].pciDomainID)
 			snprintf(worker->name, sizeof(worker->name), "CUDA %u.%u (%s %.1f GiB %04x:%02x:%02x.0)", devid, subdev, devname, size, props[devid].pciDomainID, props[devid].pciBusID, props[devid].pciDeviceID);
@@ -1754,7 +1773,7 @@ uintptr_t _starpu_cuda_malloc_on_node(unsigned dst_node, size_t size, int flags)
 	size_t cuda_mem_free, cuda_mem_total;
 	cudaError_t status;
 	status = cudaMemGetInfo(&cuda_mem_free, &cuda_mem_total);
-	if (status == cudaSuccess && cuda_mem_free < (size*2))
+	if (status == cudaSuccess && cuda_mem_free * FREE_MARGIN < size)
 	{
 		addr = 0;
 	}
