@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2013-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2013       Simon Archipoff
  *
  * StarPU is free software; you can redistribute it and/or modify
@@ -215,7 +215,7 @@ void starpu_sched_component_destroy_rec(struct starpu_sched_component * componen
 		starpu_sched_component_destroy(component);
 }
 
-void set_properties(struct starpu_sched_component * component)
+static void set_properties(struct starpu_sched_component * component)
 {
 	STARPU_ASSERT(component);
 	component->properties = 0;
@@ -369,9 +369,10 @@ int starpu_sched_tree_push_task(struct starpu_task * task)
 int starpu_sched_component_push_task(struct starpu_sched_component *from STARPU_ATTRIBUTE_UNUSED, struct starpu_sched_component *to, struct starpu_task *task)
 {
 	int pushback;
+	int priority = task->priority;
 	pushback = to->push_task(to, task);
 	if (!pushback)
-		_STARPU_TRACE_SCHED_COMPONENT_PUSH(from, to, task);
+		_STARPU_TRACE_SCHED_COMPONENT_PUSH(from, to, task, priority);
 	return pushback;
 }
 
@@ -498,6 +499,13 @@ struct starpu_sched_tree * starpu_sched_tree_get(unsigned sched_ctx_id)
 	return trees[sched_ctx_id];
 }
 
+void starpu_sched_tree_deinitialize(unsigned sched_ctx_id)
+{
+	struct starpu_sched_tree *t = (struct starpu_sched_tree*)starpu_sched_ctx_get_policy_data(sched_ctx_id);
+
+	starpu_sched_tree_destroy(t);
+}
+
 
 /******************************************************************************
  *          Interface Functions for Generic Scheduling Components             *
