@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -513,7 +513,7 @@ if (PARALLEL) {
 	}
 #endif
 	STARPU_ASSERT(n == n1*n2);
-	STARPU_ASSERT(n1 < (1ULL << J_BITS));
+	STARPU_ASSERT((unsigned long long) n1 < (1ULL << J_BITS));
 
 
 #ifdef __STARPU_USE_CUDA
@@ -524,7 +524,7 @@ if (PARALLEL) {
 	}
 #endif
 	STARPU_ASSERT(m == m1*m2);
-	STARPU_ASSERT(m1 < (1ULL << J_BITS));
+	STARPU_ASSERT((unsigned long long) m1 < (1ULL << J_BITS));
 
 	/* distribute the n2*m2 second ffts into DIV_2D_N*DIV_2D_M packages */
 	n3 = n2 / DIV_2D_N;
@@ -543,7 +543,7 @@ if (PARALLEL) {
 	plan->number = STARPU_ATOMIC_ADD(&starpufft_last_plan_number, 1) - 1;
 
 	/* 4bit limitation in the tag space */
-	STARPU_ASSERT(plan->number < (1ULL << NUMBER_BITS));
+	STARPU_ASSERT((unsigned long long) plan->number < (1ULL << NUMBER_BITS));
 }
 
 	plan->dim = 2;
