@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2011-2013,2017                           Inria
- * Copyright (C) 2011-2015,2017,2019                      CNRS
- * Copyright (C) 2011-2013,2015,2017,2018                 Université de Bordeaux
+ * Copyright (C) 2011-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -18,8 +16,7 @@
 
 #include <starpu.h>
 
-/* XXX Why cant we dereference a handle without this one ? */
-#include <core/sched_policy.h>
+#include <datawizard/coherency.h>
 
 #include <assert.h>
 
@@ -602,8 +599,10 @@ static void pack_unpack(struct data_interface_test_summary *s)
 			struct starpu_task *task;
 			void *mem = (void *)starpu_malloc_on_node_flags(STARPU_MAIN_RAM, size, 0);
 
+			starpu_data_acquire(dummy_handle, STARPU_W);
 			starpu_data_unpack(dummy_handle, mem, size);
 			starpu_data_unpack(dummy_handle, ptr, size);
+			starpu_data_release(dummy_handle);
 
 			factor = -factor;
 			err = create_task(&task, STARPU_CPU_WORKER, -1);
